
# q-expansion of newform 336.7.be.b, downloaded from the LMFDB on 03 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 336
weight = 7
poly_data = [67092342823114813648122566881536, -1856006326511378662744528736256, 133119631348065885186640088832, 1899098090360086301677734912, 92356576772417633969303248, 459599574384701295369856, 14284041052116936853136, 45477213592447225056, 1540141719025352521, 2760372957335864, 90347297374318, 62397711008, 3832175263, 1026048, 73142, -8, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-230200067526281992020621972646247742103881972298742957335408489626411431926859484866511472529596389188073570039813880431989760, 344839379609680988537191351937188583625645041621208486403018621251686824826150605149524371917871090165375443142904253309596208, -406749925233380837976795808837841176681667902119317664514455513718438910781068953758250354619967797193713380355984627415216, -8566678530807724485892409328308570323124450455546061801050495083888509989273559908064808164216649122375460362249834855040, -76136390396860480552410091478474891162799205512224287831030098493805897374348121977716446937046521080787346545454565281, -1296722810498114690037006266758635774353804518230866569550865651486073634138138709314606701759077948875338172627370336, -8169862003788853896534054882114672188270484968477189482177778827618425130827068473841946186891627210456344056384239, -140170927607440039161441583119199987101307658841919466084583430001094976426646099441721453803081926474784508547778, -496149740672707750804748719995351852308552818864049867970873383844115193667110198752039789984509729263793199925, -8045271494623383380780816810893797297015349032416508643975740191781516421462592118942452861354440965572728708, -16552950091970637189736800986106552067503912945860148168869166529366491006634433328376101292426857943422269, -344100011179305232606382841208031565266653066922511998190367254165713426930952843454358088596472401484222, -304265403032123063631947792002862437420303412519145227558891519890607248032665883863258216137862194479, -6517062890782438563792651785866742915364208944529882971395516699852082043017378444639386629569341500, -2218495963362924364236587223014085770201094327828943438888700649205072716110636103993462001993609, -90589702692170760714190286105730999824198621992693354334447297231604652834054077702709456867754], 355101908183499371407759350088995067525805653757910648029742997625368314518719935628697045971827754846302326918233334829909936], [[-230200067526281992020621972646247742103881972298742957335408489626411431926859484866511472529596389188073570039813880431989760, -10262528573818382870567998151806483900160612136702161626724376373681489692569330479172674053956664680926883775329081520313728, -406749925233380837976795808837841176681667902119317664514455513718438910781068953758250354619967797193713380355984627415216, -8566678530807724485892409328308570323124450455546061801050495083888509989273559908064808164216649122375460362249834855040, -76136390396860480552410091478474891162799205512224287831030098493805897374348121977716446937046521080787346545454565281, -1296722810498114690037006266758635774353804518230866569550865651486073634138138709314606701759077948875338172627370336, -8169862003788853896534054882114672188270484968477189482177778827618425130827068473841946186891627210456344056384239, -140170927607440039161441583119199987101307658841919466084583430001094976426646099441721453803081926474784508547778, -496149740672707750804748719995351852308552818864049867970873383844115193667110198752039789984509729263793199925, -8045271494623383380780816810893797297015349032416508643975740191781516421462592118942452861354440965572728708, -16552950091970637189736800986106552067503912945860148168869166529366491006634433328376101292426857943422269, -344100011179305232606382841208031565266653066922511998190367254165713426930952843454358088596472401484222, -304265403032123063631947792002862437420303412519145227558891519890607248032665883863258216137862194479, -6517062890782438563792651785866742915364208944529882971395516699852082043017378444639386629569341500, -2218495963362924364236587223014085770201094327828943438888700649205072716110636103993462001993609, -90589702692170760714190286105730999824198621992693354334447297231604652834054077702709456867754], 355101908183499371407759350088995067525805653757910648029742997625368314518719935628697045971827754846302326918233334829909936], [[-5952973548609950270754444462254194565818864849866588920119906098774048712629579764478550338222673221406804462454309451738469968, 388072600265917412728970141827181349113775065403594290566639076144188655961498308484997599571018781099891337318521824648765056, -2203489177727661279016073564049789280783395983262646994095837038421743146057940784147377675413839014710477094200982143424816, 226144515313583652852228276201471914603068331523965905596991467720034977677112690636955306412048727125162380043945739732528, 123987308930906722992910122104693474865093947605137023594056416143447055199118745344309621068219465603879367192521624767, 33204678785404055130027070875784532094646854422829297607952782023137614346291272025095280942241472366531091952117171521, -5434083659709503654438949860034379749827553577437293370992621169122076530629241318805025819238817399349047501190447, 3909923817573272761376729773211587276170090558724172458790791541165484029331683915601971692387762740469780680592237, 153797436451850822859123716629793201677589156403476159839975231738813962283221446285834635144842254256387840019, 238043103653520284017395790889594554127632602961382526451516630072286420809755656747504728003706412348211141761, -155816263649194881697776692416040812800991960888329605234667276340556830864008226191146501800444729132635333, 10556259991904621245898852987752279842620015458645723159355812643136432008056005963384101975607630575902015, -3359871963188183438061334073246237229318544489094386262154398582340912703444703006108218304437801879559, 204798956873444200378881625538782613597319855876256313759345022760861675158572987099909196708047596787, -111067639491678140728890707701647959547527759587523294773516214911150547287115542796181926653915177, 2852623882208119689235919225754202768970484681777796919229831729826305285949014647912428200067887], 355101908183499371407759350088995067525805653757910648029742997625368314518719935628697045971827754846302326918233334829909936], [[4335672876225221987487528218080641868213144126169283394604334489951846890400796895251137774559818600837752848768924082591147464021413224185539512853122112, -746025867956113306891020317752816331166720164860728141918816894463047788540455180267438487587323716495497642822678628366186018830616865017266500867485664, -10894805761603351564647380312129242349095499200579888007685679114278249755501916278411350241905229232410231208850077151635781358172633553903029469849776, -270029785157054243032612908638841881110470483228427653862235415287448010096323202108487318236724936035582007644289749706030899808374164803514146077824, -1717235393880130124781930263646136188705510222698386456273777869103816195984155636152602116403657129422565626181434251904056191907415142668662592940, -33142698738951373880544574647182743246771754234797054648207086411574829730063556935317757013838599681506148286469575762466970884840443659747296980, -213747134113227243151498169096654454815582444119668581837697590795810844625814550689562708195763441793010356184881085633524387835012724463616819, -2963091926819551385146734322978842795013093537799291496642633027317673335874999782420027920032387755930570289590572848537749055140187781305502, -12776753521227327845625915283052294308276450239137614831205900770919277943279291368615542891436612738171309400442724883445067822496307622302, -141159703886191865980804645571748647303333984642824685285990784014863483255538697897742505052145592480081574942438868297060750558041111504, -592429280388838298207254040272233190817476470310512982198019975318363259370688878611224249549635751713247340247230979650067224095554133, -5178060000201226059575912048184406071778521176683385335072211997907431649901900418408076621279707768133068252229071128330467819728682, -11459745220221746186655654561313490791005079669691837102905767388499423209811265917226248274935855362600666414699751006373248230494, -89809584435306059337407174905394260557572704948050057080932934092076992738406620398316146099959462044317960196857665645665899632, -155039201537387278900611641913002361928785263316460512170682623975847803298417855146366453652765527261055436753471523156318947, -1175842542203148919058421333213370051544683878390424703783124004625945701783851553614826329088643738035877031444929889957294], 47934934472322871719035498677670621204022943978763099707503665344811666110809666566314119150112657827601708634408074804305467205111654063648851426100000], [[-96549769695900868748637432938336678056146377823910308981105484240220843263372269382062400037840211253966495378332052898634507192195093133151993790244872192, -1894806737985502249195243807762808546012228240582446366954839275382919259796005482530504522503674318460171673075628109838707208077380442633723684359367520, -99001802266849687262695204338465075959831424346367585766723822971676484873322378172934790244199754177327533312365234512894909808309694752346572572110848, 160123950037029377682248823292412420161288132358317007990016952785354792875446270522005215890983933845286317007446935501927182200612337552238955123904, -16669570599947152364142109392766147916858490250330773169397426879313249781433635032170399943148530285500431076628580988821092695913692006278238108612, 89347946972556501908343390307799103511351796345267598115027904573773212042419075102884797614513878975175934044244452038186784280828106444572516854, -2181787856891504603771737399349840095513330310403736815580659271092631295810975350529012842688003075123143236618740774071675107689264788576520889, 12485105539922756070644067516407562270707321251668770965114893343058848718321593187244488341328692824111430340349569870727965582830211487655606, -143970878437387701205166765006828527252053706769126674527573318653412853236179547774222467449282672954184334591796497825044420127991557255322, 973031522222800533833072996235364969168599369147989751187130724134158128148935987991436026802251951924450956570230029254614530751922369126, -7368848367755408914681111596324228610543574243383441491763574573519557497627592727726343254999710400674001624987349088311737036421504463, 40725447228562764495391834018269460743272298695142190627147249876255718914093517521910792586267354815188500179656339096101810398420410, -147806787204336485571631514390822204887330080345959509590375568855144003594794701805916420472361987953971429913299309789462220784618, 832860689329196941836959359809487322258496269636027375313637343103326119682087397471510107677006288340349085605287521466853667274, -2333793049462180880759652270220008192111322482426472147356747552125723776463891531223260463917481025345300173570747026463054953, 10252837820129107033345532639439903167428199705949160843391422388032871205897256845103620226921927657835798281841043084373578], 335544541306260102033248490743694348428160607851341697952525657413681662775667665964198834050788604793211960440856523630138270435781578445541959982700000], [[-247346787549658640250398860140949923697867970635709910847247887938147850159749658663543941507600319263569098938568823543428785524849000131644838460254829952, 14872105011420381959106859507001664914440608991621034261982553788892258830599415976798864288719772236363008751784221170320912733190362236370828888972357184, -177531487358677094694442191289337473568590051102487328990345823678031515413745793138082804271017508904103207666406369277758483393917720047634487046328864, 4583545341683720187025210547556748211882555887406273380415229806899788375344530778350285853371231915929774578714461354403130460953381570272616326126304, -33436363550778961493552734634714533736633943656595448188740087483744103937583350616340120866050149130339421491302429597226780466643081581477296727290, 719987973685650632940491061230343265284905330819686003959639893802140154027067856723965096112613534209808697223325407257336106981188003348060345940, -4292152452092361501865790728238157714290559944420335290143406957222254336620600803651978730344177614999802517380973047440085225362357300143537171, 66359137710517070252232613326625507662312699837969430813019257569618877588004920176078570906296461219331434387401572409417830242951847959781852, -297374269072043465980376667949336147493846709771333045507516160735261402003564060411371722371792377634199230413036520511952804879716072045368, 3934892390759072271294134411393473653644903555949035285495003327627502266911659364472434081375571830481156226054391035520336242279908836964, -14318091946756586613363810927302318142695455636897209513126709656856427174284095077609237582160438035418113742089076853668020053351926797, 140349616464794056237763834563245378057731330732205513749120079280052756210002752624266462910529586282007199210862980189121474851104892, -289567891276082322602590442383936616865059501829690145899421251807576012174108182142661535033453475207736324470381386287885300644356, 2653704204140365144404567210232523531206549523034996525283349356602877275123528889944747785971983773694163046832672296635354155652, -4432723262821871476289640610014136461889581099440999321072981016153275485288306127587253973179032554967372273863562743446256863, 30137465972628224884812605094295231562102032745151053868687896579306823151568844228093174988225878800811496547886607338503884], 335544541306260102033248490743694348428160607851341697952525657413681662775667665964198834050788604793211960440856523630138270435781578445541959982700000], [[58171070908170064531552758309694779989508226354407281914757270259276467359739945242942898356108293554100647667458883168133644433009715021838748834475903424, 14092534918713535268581159680601763716166570962687592411640057820498074979380852546516188695657172256644413709084575471230404541933587637277381048403385024, 112208389714323228454807619412383171633390017577798989205688084435041355637233538301087051513666147701437708884839518772326719396762226676748146073500560, 5903813672833096463172444213471742817562483548447771000634188399345980184389382244868104098650833576746505023056272130957700921400648693769598037871392, 14619115980973248999975070857336889066517557795570087296130606152665521674724145800346754791605481653360495659956964235124588871901529611041896431486, 927557481817678008697617761940987906244437855873345758072999296845252378231750126507865174101669137132827796780435531211970933763020036161106032998, 1178694007036351566708950515754254096312255883651902856340716479880229277827576416218502722433791130067763425360623338748290385288290619896286631, 92177025331438787057324950557469607342752296789080504229947522397412010904930461658076583436755432899656200435449627952056947750313506968749804, 42714032608805000174309994815739925548269847585849725943104278907984433834929457355435651198180270621554385807113590832059842889009209736828, 5276317395422422836024204200268766949123478161139249910383140194247038366284532612763714126757465987630461815901744753254030661919234253146, 26783032407254498153507215969484975190065289504360421044614995131564187158819021411738525572775008333946947359501393870686829498086137, 201955143679569491765282634743713738198814945247842398081405855789642385237335165326976159104107349473272289147744254355492843098645252, -12237671233691426714248345914304599243808413566483836148280105851036803614714471739071893146347663710852948246948917415535359423712, 3770155814585574089155018708214289058286197667680536149400265755509150186750529504657537440688928607690215108994146253249678002190, -913326696734601630334093149588859228775333367209102912158460602011295413488350492968542156896170363140448374427166930708535429, 47346475112522045957543714369682403193788166609308818435605888767709981120745583784007429049955475022318615904241446187867120], 335544541306260102033248490743694348428160607851341697952525657413681662775667665964198834050788604793211960440856523630138270435781578445541959982700000], [[4759516571432657183587146536203048383985311294331008197626140038565617856514360508746580674516699388561664691864761371832243841807646397503823129406518336, 50320267651108368744117581504984608561566508843444003011354814072888869605714046897669609496010173324950614417802634237474942047038075991025161227492064, -864417204606737448170075389964636970647110796028906048546427838210814046077613737021181810737337382048164902082008475761952610198822406143274170697792, -93913893579650924595326157158663576211858918638603301956629872882573331778931268861076410997712313829771618810323776271485758229554250567077712245952, -469409102877467193727859311707985938659797961686670217226774492663703357389395648253291969133749460896898684223503231316490441521344238777831935422, -16928283432936745072465895522057845181706709979040974837341026082349366284540125721874193387990371816168592745565845256444861969375259433307975066, -33913809980130736449527354699692134390221104603154487970531393357603618581593916302839973351484236046911595538498759248766854117498996572625375, -2163671686655078312138415986929412741998395729465038933688643095909642887842263660826259251027532368079898699334794352377261291892833870107482, -2034469063548848285680940291374064887463037385993740265375818464983284113022036221906305986674668417213522848775038438163666630169022344060, -139576272276242991804329610963686115870629281373127211097253912644108903678539873628522902996381190592616572225911767947496193446107051450, 44767147273396843466495100880683423651790525316427645431043303740621407466744543707833301309199470675848679334904778796493507610123135, -6428527485856340835288615516664899019378480808308541246148403650341160370943527621109365915024103073983554518208598810734517778782998, 1226939960120627883877226366823694422369661363967159937790935480881391688882531964233522008397086969307839788174732468060536206096, -126484529563869211707587764197248421517614985651862083831673611925530198123326085630298449085663876737196136701840217947947051334, 63391879540427294058875731060966322522961500550313267759726164191835427931425275418060355076504764152450302386685382914238829, -1788704256970431463704708346074373228063551156454552360987644116968134637908798147525693319764214731765095300003969070155958], 6847847781760410245576499811095803029146134854109014243929095049258809444401380938044874164301808261085958376344010686329352457873093437664121632300000], [[249152134637662122992976462440612678096240735717911350786592646639285991761413991713566728857596768716431610580508810531360492425199807163545170199637046048, -5142909973438102537735730096584266122727863557172586760101308189951571250724438591561226240542818922939308477444298558566333756142289560115593141709482304, 201650982809203919553954268404992989332348483792991121016438096508700679837508878155536213581341755590531878639653774349344171189582159336540450418410608, -8343032630479800069191988694055032389926732911070822245629973039933768525269637598439260606318678025882834430426977753695306210776728919074251544094656, 18708501762316210893920593789471814606117092794944488912314182130716075646169016254377732113846357380811417461460461386975547880382819917486929534706, -1516839920224955410107793988115095628874750280580184557883473465710141322724277414597898439576895221822829848381574003798359042589330847110149137712, 3585128182401182743863372776627859712741165827233249733278810984986448803671357347711473134209943428511051523581628315614010994277518203493723543, -175384669261622541612478370278398257760048276953848541771369776513949368215687524208961463790483183738194427762403906721840011031186717942182750, 239724402554583124055083691950805316221393734376104799013019855056449108144567171657980105271349996157036118798342654023841985813167017557224, -11101673825088744178489617567558753898196233172292328415819317655455317261046176591802477524634990862889830842157800031394013430518388290612, 18748188677222497190916693031556227655998074367537313737186218408478266280981885615701400223280287921973019620685341040587437427751410121, -475453604493666209889562323272809665098973442709500256393691527408675750914061304042693519698333267724765027767544705518867901897889562, 391010279959989273364572103733244734002804005918095049383164634847404361695295763697607819124676962263218954518093673983626113264500, -9276256962080586595586221157202523157874145841148349703313834510759855292516207375852874348316296076773073241293765799625700812924, 8314245832189960285489297232621141109445860104913650435209954799253062970327301670530754653578383955001206396510943797430562227, -124351820769022631096824246735940197780689343857552526320054283862098906269417163719535413629059392604165925227350825546068918], 335544541306260102033248490743694348428160607851341697952525657413681662775667665964198834050788604793211960440856523630138270435781578445541959982700000], [[274494520997854281593662348022906468326202315984127908630793384795543824108458344131255380345594010737291959094773101050998266415569767396461160248927538368, 11276494673897154949422332084879143223258869164337538285574716251888032212263940056040121469871767403392404570251123528415232837055299227514671463117150752, 262678361085413700536231416931380326221032027581285296449914486891694822159065622438737888087632449284149345353770725545057052515123229253119102896686624, 5773174191678418760039219780327332013197708047354633452926647498015675371641072649528042580247085481441119413029774049798711990692580741884371093526624, 58201658559138894101018950108501154281712254736392445178357761962979249559525088352922085785364157705872557472768438692084265155664676584208034516749, 811861008732630234731072733378454659124746411333969353535793437649305199546637403605093909481411592127051699564654845740435754978207051598244930247, 4968256660701992134143205971299575654620774438263879385872746424630275791585312581534978646446742552158355780176451937599438606566126901437367765, 85685320971179261266929193165856276098031422408827458658138637889405870597702306881472866706052288191387472841896591242163886236171825775089914, 306406294523797262257997702715910825988123488208894100611110227656129296814649210565496378752925233042813085517438281258654976546642242228365, 4988183912417033706951563376183879023084169468191148830367173477400794372868523986331836745559496994466117195793994356563073536611855317465, 6492535882575436291020054526996432533146179087799852177291364583619941406743711938696394415629366612950913762615280970481622706199970335, 227363740743147187577173294230010958182348011436211452205096214476868077248482626611406073894010193909503421566154694681695464531244786, 109409419877857883791907448449442729866179605212972163807633638815527015204254182110807583064166170885501274074596329165725568457383, 4409808230566070581319596897241825652155300022009207100705721018039961890394387877689800564781025500558508848228659421174899741023, -581997731181417515960268335811654205069072789305499899855151948580405341084266947989584758155589042590574258184778958631329473, 63840286482930668018423007382719005466196007070152009863673497031309021086379742551221108857450389775521313403090165690415376], 167772270653130051016624245371847174214080303925670848976262828706840831387833832982099417025394302396605980220428261815069135217890789222770979991350000], [[309363704767834981966873470063068020432372477000150182086654294025388566430329959274594572731717633744343339729283628781308623249320720198004856712734899456, 517716439437053248526723365946613925594710317962262968662735836900550949640045331638529215594891822231292495522897644230250124515856185316655511811537360, 56161713530761656522907345922211280427847412943195722385176850129198297316864547611982772624835294936381652333058670369242751913752491918376383572577664, -5358500159100678762041113736668963552185416345185308214282361868813124915640142865913650389565255889687219312682888925388525086671241734952183935477072, -13811197158246008439108437860629274637094325165491578071406479527820796395776968683711333436434910123624738261892559548513343227959422501769141301934, -776755676533670712563314285321398902750709288679584847367168831941578264153660395540289769464238932050589915693068243254625172552856871949256566497, -2116255196301490860894623839997140026862729723431282758873812466317552800257826524268712341467784237912844533104134551751224117452988445736759223, -89718270641855863978691822414796113977346104270595123681343775386661736218559407406193991475172942158637365259799782391484399957993552111362933, -213082754282962463473972414166031974820329994008275170004644263933887480923461177530453875118187134031382799692869183144338153409416866982004, -4932998385298561124102605651588943384171131832902691691060873175443899862794605495451085609168532027302094350533941182881655672861137595993, -7758200835803494117199473552839554180685730131487079131871130993542253807164385281825009499028413713660275406472911542143189915174238241, -227401977061466965988664690903889829840166415054397800273797021983671904340500841707166317180408806008708146530920313440437873280240655, -162254438431455702886520890597368757074186327731534062484828453202916242846521407899619769137408546382366805664149569368839901069176, -4321558615251610450276165635202817442395816531101966080980500260911253665045825739991482798149721622958909297207279019152756874107, -989911703308847808457426054191996094225454055724239268145210679462087966488698060743958554510238122748658780652730824865392571, -63991491835920887388677325520670491396626718705792797129025853504097344544420870325628876772470498027064441533953950972234279], 167772270653130051016624245371847174214080303925670848976262828706840831387833832982099417025394302396605980220428261815069135217890789222770979991350000], [[86463396080509559605559741000913469680449708437512642704189838375499508723910020208099054052811665999330080623120468039003741157401385575798028450381590688, 14483515735824862617949298011482652207011099267778358575740011500676817651541144037044035800476048098456608039792594941981358718530312216700806090584940064, 215386809045579662472406559348082535581835809262225707553761090452336777052639730628269732828953738344847265658763208087158837551788397519177697679889376, 4876286538443292405286348927770519042712968960693980729048751560315617315320489496758590786243195411124716431671167903600986489652321283572166598017024, 47808344748428096471650448033972479326746157981136205771480272158729663076069541704105698543146558621621151592925533517265744240205611743319159354965, 771016773954954288709522528301091226778300346376685706880834301204362863700431731171408091418895964523913621985272920405183818474002271457258047830, 4294018184272195367288884700806392495367809147883710225640764440841283595450829558836146740256173845175790661812939401641114106180232622890831844, 82669047848609650186375812094525374344747057724967733247903720111563258759389120642548343866873584209523309950828633622978809058688987388649252, 245189116407551110376524451399288005448267027342980230330880161129604036643361259330539956448287378202326453407997435437893134085299358062327, 5300573770907468983946955449035634758280013402712493571313487525523612721718816066894909479208366081075403338394960887677261238984656233554, 3493086528697669203788031783492499116135321992072506714856615100253571752732866069323150662480174735210921562296941821185260327432926608, 236932385544998307194328622555870017733035396132255437465965328488014533457620571099850246165983907432745758469113349072309800621816732, 42839838431887907103988375111032045910342117096044912261347123219980622680819151523825416544074409585358311186808716912820840249969, 4664123359784019967661019900859780987310118048043403055420304567750426495723314966132916819130189025164033862329532547834253109982, -1531698918868424217152788536850668435351229621544039496997521704636750293951631793916137880545350141338898067334831855192062578, 64977486662754563234211424441504900039264753343158340403663575634877388098323791250747683555616459145681282640132167436527744], 167772270653130051016624245371847174214080303925670848976262828706840831387833832982099417025394302396605980220428261815069135217890789222770979991350000], [[2471503485897764988452214580619873087670862302393188490024997078788048507547088238976727262744713854689414757341653253888304105796397186318927955910039484576, 182740260003480171557866713779701903456893540850083580723179965195701749243592791057560972612718547216147693317402134194117346916891612701720156017969920, 149060418234957766460369743303755298755214227338121114383605631489848782875498425689220094932876513342101596409849330521378706285455178085633769580597504, -11847943480451505793149274102133200892301234357848832365872118915723812120015907094566835306265061881260695679029755409867327306298758080970658774180912, -29229559542897915567752739239833395093148253671791561864518423963109636154712446322709645745112172444554537835559781718752993104686226492182021841084, -2188808346134063408871423775472910930766084070079104592354126437365510396610098301661074470650410991234316941727307708002816609177140481544091059972, -5625483508003126131600094416384969450996496151777480383732452242342044127208251068852438592564134188030118416354839871194103732747030516125708613, -254299492241514027359431805128883582718055153868883959449800740016621633896398938096771377964493489713679145821305265808875781330839644772622728, -406642651084594339580028569718845813685795839806721339616872138931227758402539139849097699853062266571386931548751830304870800281292340526074, -15407404594364878042126959231855024903672632305758464851364008978845117355396356134720596886203497397662463422846076557904570704132061442508, -11280727712089801679956370417647039371948389375369968438569843778841883119472261403543914246189345514456196150311822653802783345622690771, -658334979775624919746669291531148261209642178082555691357088554150396561135681640791439206645234157764493921375654077009807790198668000, -200674576448860349146446149039804328834326728919905121813272880406391242750188369086854074313233337477530611906104337520768999482266, -12601403024791562752252485877437430270853346217242170739364923841632920826809278464368242868091251787257730910138022808312538883852, 542970159269235980333285710143565691140596003277093297820370908806423251537150029407483898158621156116808074925508259997634459, -171873297971798775381820496562575715310168288716963139257553553302847079090117061335220968589473597634243110887042608688710344], 335544541306260102033248490743694348428160607851341697952525657413681662775667665964198834050788604793211960440856523630138270435781578445541959982700000], [[82025831924872386517462283348882049801341209802965804476214445223784261565144569195196319970730280768411136217365597325280261923506218369573736191797118384, -6041031005471465662140959291966898589552803977725942281640361136854678356067082279250886700593702853310304689694832620302580696997158665849960891021234320, -122277267230802265826787013482980886876057426834257699597028420950683118034340094058363804464481691632153510090773637859782152282810184310099029480028464, -3874545719533816939342750729318391032930117258927501821645150843614912096854283751815421275174119258202498660403892274110839740634883498334834401462208, -31609416828267514837653501644840769964120791179451035503910714768674773318145847858369091722281942616620073968368318512073055808915022913080236758131, -600048677296761960967723772873978627845945860871302632971670292053497015430733644364438894114654186288395406004862698443711657025122460341747933548, -3474690089433253210861170470552203907410411332448469199455952532582187418105061487818210113562775020237165327921591704940331686653966131053656267, -64203825963257045611888650216208752392467677352857193816536916897054448939568541673282999087469772259167090475963830110451884462308095579863227, -219880245794728249582829991539337357266350542433216795761730048028410805963332562256583595163741162544855335208525203227161931513150407071291, -3756833426921566808917458244334577085981751227456042934989019251594523181192247594052340036836656808487388221424150064639850452221193320822, -6824438946536425056104205483175691046215742432822664866980737227149851596898312237388249516042040609144965353381435051033448678723281689, -160174708237545855698106834071104529527142531521428107446050387224006392697253840387293753887246962956429398613092797009343783507715725, -123943230952534389038993913730393868485522483488750505940746229185115394911876416339282242357090953990745803127035335679374884780369, -3050389449784830205181642391741626808478185123012545351745349391025815137348807410099295749197830885148887264313936598715492443118, -684752915260107893334777767456750974035962741659117942961352073557848820194465410128917992145981185382774786131696786289558769, -42086096596869852514137491298893818608045706501412857592010246095622785263270732506426504542204250899790208522419221836971171], 55924090217710017005541415123949058071360101308556949658754276235613610462611277660699805675131434132201993406809420605023045072630263074256993330450000], [[-487317049331345298614335923155808571894342065931718671425997064508839942906700620895035603695650247243204963338054034952744637286779602818025602868153394720, -27903009648147704071429797040646350569248706294219516909534464608422807857598589256359980775231151712901276344378216673537818701839418123226464483576362848, -882176835515404709696596123052408947771675575597582547666915132780371661260772907434332084142097289599004328905469136826961757421925095625203766845409968, -17782425995005399783655354088074175517391854019872897317068028310336311822589320629567841340726711046508685786572069633091079079668672948900820552102720, -168641527168937540479250643128045772846551710269319106526572544344261069413002122960893546272632545943130128572214749222987803004479116133941008763954, -2584979406631612121166025700718883732162984133711228547001872963168402150537681375948432472401711148333015140589025929800569060899170986950786666002, -17174743093496130930138777716590372882002079725918281343285342695104849177768923334980335163108082634551751246544176693911387258748807689252261846, -267558012719704463019880531797946889513939684589586015971949696041362652309818172522606828246306666220542096880936901118846316694083673114442907, -1025327082917251629023363620690859821816844792275398155735172061283094560807423108886509083853873345867870251567142304709927420843565745656338, -15035583567192279908024397550356435043968702065720358740013037039108417441529300609648051483944134188239423894981084598655728476063379703936, -33959988793960317810291074991049393718663131502533352626336766783258485023222585785679840213043108847979124795412965793405985513321042802, -631518927673666049044254603701558512752133239417214896101037744047671508595040102746577592061844843834437130936302731896128341969382309, -621252351266935615051282409888004679333701783221093666821808863477057370361035258190411851055765082041797885575933207660407214237454, -11888769398356636668400747733341564398245052445172467594454349512609377113566839206258152030495227895790764130526910395270703001356, -4759806909538320824014664089906091735243267890986399319591994218154586038260146424241818352282786327963373369517587122961426290, -164115587296466618210502101991681868306853412483896319534024177131854737157213678114706705486823881405413491912705539344234887], 111848180435420034011082830247898116142720202617113899317508552471227220925222555321399611350262868264403986813618841210046090145260526148513986660900000]]

hecke_ring_character_values = [[127, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [85, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [113, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [241, [0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-9, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, -7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-26, 0, 7, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [80, -2, -81, 1, 1, -1, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0], [-45, 4, 0, -4, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0], [393, 1, 392, 8, 0, 0, -1, 0, -1, 1, 0, 1, -1, -1, 0, -1], [468, -1, 233, -1, 6, -1, 0, 2, 2, -3, 0, -1, 1, -2, 1, -1], [-1003, -14, -500, 27, 7, -3, 0, 2, 3, -1, 0, 1, 2, 0, 5, 0], [-2754, -19, 5, 19, -21, -2, -5, -9, 7, -10, -1, 2, 0, 2, -1, 0], [3306, 6, -3302, -6, 4, -1, 21, -4, -3, 21, 7, 2, -5, 0, 0, 0], [20, -19, 3707, -24, 15, 31, 12, -18, -1, 6, 12, 6, -2, 0, -6, 4], [11508, -93, 34, 93, -104, 26, 13, -38, -7, 26, 1, -9, 0, -10, 1, 0], [1118, 52, 2225, 80, -54, 28, -42, 22, -17, 0, 10, 8, -16, 3, -10, 6], [6893, 68, 3416, -165, 59, 42, 0, 26, 4, 9, 0, -3, -1, -16, -5, -8], [-17117, -43, -17067, -236, 20, -118, -13, -3, -29, 13, -9, -46, 55, 16, 18, 16], [-3301, 350, 3099, -162, 248, -145, 29, 54, 8, 29, -37, 28, 65, 17, 0, -17], [22, 970, -7098, -4, 156, -5, -24, -10, -49, -12, -12, -6, -7, 0, 6, -12], [-10916, -1322, 10668, 742, 316, -301, -111, 160, -36, -111, -37, -2, 35, -1, 0, 1], [20763, 122, 41679, 580, -180, -121, -277, 198, -182, 0, -13, -31, 62, 6, 13, 12], [8175, 285, 8256, -400, 76, -299, 144, -140, 71, -144, -11, 145, -134, -14, 22, -14], [81316, 76, 40796, -374, -519, 399, 0, 121, -175, -201, 0, -101, 11, 8, -79, 4], [-105939, -77, -211083, 413, -171, -755, 253, 225, -211, 0, -95, -20, 40, -21, 95, -42], [-140, 1942, -183390, -24, 808, -602, 348, 22, -266, 174, 92, 46, -60, 0, -46, 36], [99345, -2390, 417, 2390, -17, 156, -222, 407, -192, -444, 205, 22, 0, -52, 205, 0], [1282, -197, 1924, -3823, -1386, -360, -125, 281, -755, 125, 49, 84, -133, 110, -98, 110], [-36571, -2101, -18033, 3851, -818, 1449, 0, 475, -293, -228, 0, 124, -48, 220, 28, 110], [221330, 221, 111042, -1521, -1530, 3135, 0, 1172, -902, 19, 0, 93, 11, -178, 115, -89], [-106947, -73, -106611, 2188, -470, -895, 306, -15, -354, -306, 126, -88, -38, -72, -252, -72], [122906, -4891, 282, 4891, -9, 970, -247, 523, -526, -494, 16, -99, 0, -217, 16, 0], [51104, -4256, 103352, -1484, -2009, -346, -297, 1289, -618, 0, -195, -97, 194, -214, 195, -428], [566097, -7865, 283514, 13990, -2985, 4773, 0, 1460, -1861, 937, 0, -280, 29, 100, -222, 50], [69416, 815, 70310, 11431, -974, -1934, -579, -135, -1229, 579, -165, 680, -515, -86, 330, -86], [-365612, -3462, -728163, 1370, -3946, -2190, -744, 2574, -2003, 0, 300, 158, -316, -43, -300, -86], [710, -9080, 123710, -1074, 4712, 560, 1098, -1195, -796, 549, -242, -121, 153, 0, 121, -306], [-158953, -1675, 156242, 981, 3763, -1705, 954, 601, -715, 954, -462, 314, 776, -346, 0, 346], [307334, -564, 306356, -17502, 2434, -2578, -1458, -380, -1100, 1458, 124, -944, 820, -372, -248, -372], [-883816, 3404, -441718, -9524, -1302, 6676, 0, 2714, -1040, -570, 0, -2, 40, 576, 78, 288], [-851681, 604, -1702319, 2366, 1552, -2861, 787, 322, -780, 0, 583, -559, 1118, 80, -583, 160], [-115, 32142, -704326, 1069, 5755, -4077, -2676, 1515, -3785, -1338, 892, 446, -1471, 0, -446, 830], [-672673, -5068, 670176, 4569, 5018, -3660, -2570, 2917, -1506, -2570, -535, -1153, -618, 331, 0, -331], [-2054955, 8776, 2570, -8776, -7529, 5328, -564, -2013, -369, -1128, -188, 1168, 0, 288, -188, 0], [-1038851, 4744, -520156, -6035, -15, 2355, 0, -300, -201, 2367, 0, 3153, -1476, -396, 201, -198], [1868269, 822, 1867781, -2350, 4569, -3614, -408, -1809, 934, 408, 262, -987, 725, 1378, -524, 1378], [831887, -38253, 3817, 38253, -2139, 7902, -1232, 3571, -4232, -2464, 962, -941, 0, -552, 962, 0], [-1358872, 13391, 1358688, -5739, -1532, -1404, -1437, 375, 841, -1437, -391, -1538, -1147, 752, 0, -752], [1103980, 5117, 2214476, 3259, -1528, -6664, 5205, 388, -1045, 0, -119, 1317, -2634, -90, 119, -180], [-2332458, -6028, -4666455, -10760, -528, 8145, -630, -2934, 4531, 0, -1874, -568, 1136, 702, 1874, 1404], [-865320, 68540, 872731, -37113, -2493, 15183, 1051, -3772, -1826, 1051, -292, 1914, 2206, -324, 0, 324], [-540, 69667, -1336349, 2586, -155, -5099, -1860, 3410, -2079, -930, 1648, 824, -1520, 0, -824, -292], [-4559, -446, -561398, 6571, 5217, -11680, -4422, 6305, -3027, -2211, -532, -266, 4319, 0, 266, -67], [479608, 552, 951404, -14576, 23836, -6642, 3344, -8540, 2028, 0, -26, -976, 1952, -160, 26, -320], [-418448, 4023, -429447, -38802, 11189, 18533, -4254, -1189, 7829, 4254, -323, 2834, -2511, 438, 646, 438], [-3304705, -4821, -6615079, -3519, 16955, -3843, -5961, -2461, -787, 0, -2757, -3112, 6224, -887, 2757, -1774], [-8329, 42466, -2771562, 7711, 677, -12818, 976, 5396, 1395, 488, -4630, -2315, 5270, 0, 2315, -2185], [-3588106, -59116, 3609434, 22426, -34370, 31344, 284, -14890, 6480, 284, -980, -626, 354, 272, 0, -272], [-1625483, -11211, -1613688, -31765, -41122, 19517, 2574, 13190, -10213, -2574, 484, 1979, -2463, -24, -968, -24], [3719067, 17131, 1855263, -23235, 3427, -7376, 0, -7004, 1786, 6591, 0, 4023, -3641, 2272, -3259, 1136], [9709335, -4173, 9710585, 54710, 3259, 7859, 5868, 1912, 8162, -5868, -3036, -2261, 5297, -2528, 6072, -2528], [-893540, 9667, -5736, -9667, 11219, 5020, -1011, 3759, -1024, -2022, -2006, 979, 0, 1711, -2006, 0], [320354, -92111, -323028, 41007, -16594, -5573, 5616, -6437, 10037, 5616, 766, 3660, 2894, -1427, 0, 1427], [-4562294, 12726, -1355, -12726, 24383, 27544, 466, 20389, -18216, 932, 642, -7393, 0, 1786, 642, 0], [-9436358, -17688, -18909487, -62060, 8928, 30120, 3342, -15152, 11913, 0, 5158, 7034, -14068, -683, -5158, -1366], [-4054278, 44992, 4090386, -30538, -39863, 43198, 5064, -17339, -408, 5064, 3872, -1255, -5127, -1658, 0, 1658], [8394, -126464, -9367723, -17226, -54782, 35431, 18564, -13804, 22515, 9282, 6844, 3422, -3929, 0, -3422, 2972], [-12611, -72351, 1067737, 23597, 32163, -54035, -20870, 26444, -25415, -10435, 5694, 2847, -2060, 0, -2847, 2296], [-13552516, 48285, -6778391, -81163, 34004, -44173, 0, -9799, 22318, -17988, 0, 5608, 604, -2098, 6816, -1049], [-1650835, -45912, -3862, 45912, 8395, -80621, 282, -11561, 27373, 564, 6116, -599, 0, -3066, 6116, 0], [-3055017, 224346, 3097930, -125599, -57494, 53012, 19056, -28883, 2468, 19056, 5239, -2031, -7270, -3807, 0, 3807], [-4249720, 55952, 6844, -55952, -22227, -9723, -8952, -8099, 9767, -17904, -220, 4927, 0, -2620, -220, 0], [-2438907, 1902, -2435690, 103169, -4536, -2988, 17912, -1147, 7376, -17912, 1429, 755, -2184, -4461, -2858, -4461], [-154284, -102516, -59734, 218224, -27486, -47067, 0, -19726, -5969, 9862, 0, -6534, 6611, -724, 6688, -362], [-4931328, -379281, 4901122, 188613, 15638, -34485, 28062, -2715, 8316, 28062, -310, -660, -350, 1362, 0, -1362], [1544, 139653, 11204897, 5042, -10773, 4255, -6984, 3928, 3147, -3492, -2228, -1114, 766, 0, 1114, -4208], [12213066, 217611, 24420571, 192165, -22284, 28900, 111, -6284, 10022, 0, 2897, 6439, -12878, 4107, -2897, 8214], [-6268851, 164640, -3132210, -320249, 1651, -3171, 0, 272, 6763, -16543, 0, 9303, -3328, -7216, 2647, -3608], [12942026, -29419, 13012753, -24064, -131382, -27003, 11934, 30314, -53019, -11934, -434, 895, -461, 4906, 868, 4906], [-6718, -395657, -27151921, 14100, -9757, 4392, -30048, 7018, 3104, -15024, -14164, -7082, 15075, 0, 7082, 560], [-13937, 113338, 8278974, 1497, 42353, -34438, 18796, -2256, -13359, 9398, -7506, -3753, -13842, 0, 3753, -711], [-9419021, 14296, -9450729, -5414, 106340, -38942, 7374, -32076, 37570, -7374, 3650, -17780, 14130, 5788, -7300, 5788], [-23715374, -39672, -47413536, -98872, 74632, -49836, 8698, -29684, 290, 0, -5236, -84, 168, 7004, 5236, 14008], [-8214447, 157008, -9204, -157008, 9243, 40726, 8832, 6107, -21007, 17664, -7636, -19624, 0, 4632, -7636, 0], [-380254, -21124, 365361, 15339, 97319, 19709, -7915, 23544, -29794, -7915, -4969, 13990, 18959, 4424, 0, -4424], [13010702, 235134, -16559, -235134, 5247, -80670, 28122, -35233, 31032, 56244, 3681, 5496, 0, 3500, 3681, 0], [-15459437, 93091, -7713669, -226963, -62657, 109766, 0, 39374, -37848, 11973, 0, -1407, 2899, -2064, 4391, -1032], [-14996100, -75123, -7496072, 146221, -50614, 26544, 0, -3724, -25055, 15609, 0, -7749, -4618, -598, -16985, -299], [-21274570, 258866, 46756, -258866, -27943, 68290, -2054, 33727, -46587, -4108, 15921, -13426, 0, -10451, 15921, 0], [32926, 148662, 14895341, -35336, -118994, 126680, -10032, -35794, 52944, -5016, -916, -458, 15570, 0, 458, 6968], [22085264, -22999, 26954, 22999, 10542, 210630, -22093, 71732, -83875, -44186, -3641, 12491, 0, -7488, -3641, 0], [6493758, 336621, 13096229, 458691, -93971, -43089, 31830, 49365, -13202, 0, -11538, -11670, 23340, -2190, 11538, -4380], [-13471519, 157964, -6688732, -295649, -157521, 68136, 0, -3110, -55303, 22388, 0, 17169, -8444, 4330, 281, 2165], [-11377952, 127288, 11355225, -39183, 115882, -5861, -29819, 42945, -50330, -29819, -8111, -5977, 2134, -764, 0, 764], [26639812, -457167, -26712136, 261325, 141682, -75143, 24498, 40001, -47338, 24498, -7622, -25482, -17860, 82, 0, -82], [18845469, 69309, 37743745, 121729, 10527, -96474, 26579, 26655, -34345, 0, -5306, 445, -890, -11346, 5306, -22692], [-3328916, 135773, -1644611, -332239, -36706, 129793, 0, 62013, -45408, 46260, 0, 1320, 15692, -16514, 32704, -8257], [-500864, 272168, -945498, 305688, 37087, -143743, 1992, 28423, -64059, 0, 1558, 11663, -23326, -8782, -1558, -17564], [-71558, -87041, -58410041, 70666, 378412, -264444, -746, 63799, -129460, -373, -13734, -6867, 41735, 0, 6867, -5602], [-49065040, 89728, -49069920, 153608, -48554, -9680, -32204, -21726, -36796, 32204, 14442, 68002, -82444, 19412, -28884, 19412], [-34492860, -280647, -17261513, 472781, 8838, 211687, 0, 90607, -27850, 10926, 0, 2094, 1476, 11150, 5046, 5575], [42586, 882827, -57506077, 12372, 184313, -34032, -69084, 24044, -87116, -34542, 23344, 11672, -15521, 0, -11672, -8744], [28429148, 652159, 56970262, 773409, -36672, -100890, 32427, 45984, -31353, 0, -10393, -14641, 29282, -4646, 10393, -9292], [76943641, -25000, 77063660, 211088, -177926, -182771, 16397, 24923, -124602, -16397, 4069, -77, -3992, -12842, -8138, -12842], [-6138585, 449290, 6131689, -221876, 126143, -21513, 106167, 11531, -53230, 106167, 32853, 5993, -26860, 3397, 0, -3397], [90880, -622308, -29454904, -51744, -23166, 168618, -17170, -42127, 27026, -8585, 19234, 9617, 13053, 0, -9617, -20934], [64764156, 251034, -64964858, -106252, 248086, -195697, 72129, 56984, -17214, 72129, -14535, 18454, 32989, -2749, 0, 2749], [-86798869, 62046, -86828287, -849730, 241591, -142556, 46746, -76469, 96416, -46746, -22406, -14423, 36829, -24560, 44812, -24560], [19854809, -350901, 39704625, -203213, -244243, 146736, -124081, 91025, -26615, 0, -10688, 17181, -34362, -4982, 10688, -9964], [52988, 397298, -81617780, -64964, -210804, 245588, -52276, -80030, 86432, -26138, -30132, -15066, 2582, 0, 15066, 23048], [83401848, -389428, -83237442, 158182, -135223, 239558, 70284, -93553, -15918, 70284, 11374, -20489, -31863, 8918, 0, -8918], [79561257, 281440, -37852, -281440, 30711, -308755, -37926, -46497, 123779, -75852, 752, -43725, 0, 22636, 752, 0], [-125611020, -347274, -62842906, 640156, 155407, -124815, 0, -5041, 72245, -90405, 0, -59433, 22601, 5428, -14231, 2714], [124246360, 15228, 124298410, 497126, -45354, -5920, 21732, 1152, 10678, -21732, -12690, 16380, -3690, 15616, 25380, 15616], [-128005414, 428709, -80320, -428709, 25100, -92874, 81507, -74162, 11597, 163014, -30689, -73923, 0, -7504, -30689, 0], [-13140726, -548358, 13081258, 291472, -37186, -4917, -114459, 7574, 49816, -114459, -61979, -27012, 34967, 14995, 0, -14995], [39812558, 357375, 79331973, 194141, 25186, 209835, -170757, -33444, -6348, 0, 39141, 48173, -96346, -4252, -39141, -8504], [184261829, 83453, 184166420, 438850, 134974, 14110, -17283, -59334, 47863, 17283, 27492, 24119, -51611, 24721, -54984, 24721], [11284566, -882461, 22746615, -774795, 161268, -248022, 45873, 864, -37140, 0, -30445, -52969, 105938, 8179, 30445, 16358], [-19263512, 775154, 19338780, -454954, -152521, 251182, 110954, -146463, 28362, 110954, -36966, -11709, 25257, -4410, 0, 4410], [-49847, -105587, -102478103, 22537, -46923, 35957, 28446, -24904, 75123, 14223, -94882, -47441, 57524, 0, 47441, -34354], [14793408, -537320, 29488496, -641414, 128271, 102316, -23164, -82197, 70473, 0, -1083, -30150, 60300, 18837, 1083, 37674], [-66303061, -27681, -66230549, -1172608, -242579, 154007, 128928, 67540, 22664, -128928, -2436, 39859, -37423, -38624, 4872, -38624], [-161285997, -1801890, -118776, 1801890, 294032, -305508, 47754, 19400, 88702, 95508, 18540, 33910, 0, 12382, 18540, 0], [-127167, 1081089, -199019289, 113097, 57769, -398471, 56944, 147413, -95419, 28472, 68632, 34316, -55317, 0, -34316, 19914], [103482943, 1687190, -103606947, -787108, 118301, -267023, -99535, 120285, 10962, -99535, 11769, 7311, -4458, 4455, 0, -4455], [-208385658, -1195683, -104168679, 2445875, -102026, -13187, 0, -36550, -79584, 179463, 0, 17959, 2633, -28810, 23225, -14405], [-209582961, -953827, -119042, 953827, 322512, -246024, -53228, 75580, 105538, -106456, 4424, 58918, 0, 38448, 4424, 0], [-178426, 428, -124061482, 229944, 182764, -501710, -105444, 218772, -157234, -52722, -22344, -11172, -38584, 0, 11172, -9968], [-185737956, -176680, -92924042, 347406, 256342, -301146, 0, -58362, 39692, 157420, 0, -64316, 56946, -61676, 49576, -30838], [12681238, 803890, 25147398, 238286, 493037, 6948, 135489, -276289, 142448, 0, 3823, 6513, -13026, 18954, -3823, 37908], [-150914, 225479, -221287861, 160638, -107605, -370146, -9216, 169862, -53978, -4608, 18448, 9224, -81737, 0, -9224, 4108], [147189190, 653873, -146743006, -475473, -517158, 677979, 208344, -319099, 26561, 208344, 20402, -22026, -42428, 2087, 0, -2087], [46197058, -104892, 92218298, -292252, 345387, 3335, -57742, -103485, 39499, 0, -106774, -9805, 19610, -47160, 106774, -94320], [38450194, 27876, 19183644, 20972, 414589, -480679, 0, -83856, 163219, 27504, 0, -7132, 58532, -65368, 109932, -32684], [-189259236, -1341238, -133654, 1341238, 393981, -92885, -146172, 205373, -4247, -292344, -39350, -65295, 0, -20480, -39350, 0], [155103, 1837462, -168750828, -148729, -747331, 590496, 94192, -151292, 331197, 47096, -5126, -2563, -10724, 0, 2563, -56033], [318203417, 793776, 23340, -793776, -92163, 28827, -83310, 2481, 9525, -166620, -23982, -23175, 0, -24234, -23982, 0], [53394324, -188203, 53136688, -215591, 359996, 284768, 78633, 3859, 230951, -78633, 37133, -184344, 147211, -31052, -74266, -31052], [-57032910, 675693, 57446700, -407803, -466806, 543612, -36255, -186791, -18421, -36255, 3511, -46878, -50389, -21490, 0, 21490], [201759431, 982032, -174880, -982032, 196686, -568616, 93829, -120720, 169417, 187658, -16177, -150223, 0, 46790, -16177, 0], [331411571, 310258, 331291492, 560773, 643930, -201170, 180618, -245797, 374548, -180618, -48359, 64461, -16102, -22867, 96718, -22867], [11675370, -1651269, 22906636, -1654899, -110984, 590174, -257733, -6048, 122509, 0, -78517, -4233, 8466, -53712, 78517, -107424], [70416, -1861597, -156945913, -67728, -797950, 237794, -51346, 4981, 146686, -25673, 145418, 72709, -158835, 0, -72709, 95694], [138020832, -1774273, -137695766, 782171, -565782, 511966, -151467, -200405, 158305, -151467, -51045, 9526, 60571, 33184, 0, -33184], [12231453, -220927, 23922695, -299485, -595664, 1075614, 135147, -38372, 383500, 0, 68709, 907, -1814, -29017, -68709, -58034], [-35445061, -70187, -35259481, -1341354, -209844, -271193, -201690, 49225, -273186, 201690, -26612, -20962, 47574, 60860, 53224, 60860], [-6160154, 643066, -12454014, 955858, 101131, 108031, -245062, 47983, -20525, 0, -8628, -108413, 216826, 6398, 8628, 12796], [185495179, 287712, -77698, -287712, 67495, 111996, 8196, -30133, 41867, 16392, -28884, 103820, 0, 82956, -28884, 0], [-239338352, 420129, -239726862, 1177127, 553862, 200120, -52995, -193669, 253073, 52995, -2237, 226460, -224223, -86916, 4474, -86916], [-449129716, -318398, -224647548, 724498, 168208, -429582, 0, -186750, 54236, 138996, 0, -99048, 15880, 59828, -67288, 29914], [-61530170, 69528, -30917790, -286356, -138744, 963138, 0, 260224, -238958, 316442, 0, 112924, -106040, -16696, -99156, -8348], [98570, -465054, -152794242, -90562, 244876, 289318, 169644, -142532, 133038, 84822, -103940, -51970, 219866, 0, 51970, -144800], [341791424, -368917, -33656, 368917, -250369, -946238, -135503, -298409, 448296, -271006, -9636, -52699, 0, 7801, -9636, 0], [52938798, 582353, 106568283, 440151, 722220, -952548, 466527, -188588, -8554, 0, -106471, -117487, 234974, 47813, 106471, 95626], [-31930220, 880566, -15983768, -2210390, 42326, 571404, 0, 321300, -121858, 20414, 0, -127958, 84942, -46340, 41926, -23170], [92526194, 3649009, -92717852, -1738999, 381300, -59121, -253380, 167381, -25335, -253380, -103456, -3630, 99826, 71301, 0, -71301], [93618451, -1369996, 188152813, -525414, -612304, -651573, 247727, 371210, -250604, 0, 78859, -51081, 102162, 51022, -78859, 102044], [-88586521, -1845223, -44274591, 3759107, -104164, -272231, 0, -133435, -89015, 224130, 0, -64774, 28988, -72800, -6798, -36400], [369861, -3380374, -537314788, -257133, -132073, 638258, -163912, -184748, 1693, -81956, 144770, 72385, -115788, 0, -72385, 41613], [392941569, -623826, 291266, 623826, -41450, 1022470, 3846, 365122, -484274, 7692, 87980, -40508, 0, 67104, 87980, 0], [13089539, 302124, 12766441, -318111, 1364824, -244598, -9250, -369294, 578586, 9250, -117984, -67170, 185154, 28770, 235968, 28770], [15661498, -583678, 7543546, 943620, 628510, 403164, 0, 218698, 27828, 346200, 0, -5038, 10438, 28944, 15838, 14472], [-693966070, 2016108, -109880, -2016108, 432713, -657754, -32388, 44087, 267047, -64776, 84433, 165494, 0, 74025, 84433, 0], [164714938, -735495, 329900554, -582721, -406721, -314370, -8676, 171233, -191153, 0, 27152, 94846, -189692, 42818, -27152, 85636], [-22901662, -1466473, -11594776, 2213189, 800224, 196044, 0, 398178, 180117, -226283, 0, -321579, 217932, 31338, 114285, 15669], [727374210, 154980, 727282726, -2252236, 506222, -477772, 49096, -230154, 108108, -49096, 60372, -75174, 14802, 88272, -120744, 88272], [-84223538, -1804696, 83840853, 1229357, 1794947, -480419, 51461, 613740, -676896, 51461, 84993, -40278, -125271, 49374, 0, -49374], [312067612, 1503192, -312395450, -468548, 1092972, -729703, -10359, 501732, -467791, -10359, 125259, -64364, -189623, -53042, 0, 53042], [18587015, -5885, 18475649, 3589050, -564692, 823659, -171828, 238145, -131186, 171828, -16246, 232260, -216014, -103216, 32492, -103216]]
